@@ -24,7 +24,7 @@
 # Written by Peter J Billam, http://www.pjb.com.au
 
 package Crypt::Tea;
-$VERSION = '2.05';
+$VERSION = '2.06';
 
 # Don't like depending on externals; this is strong encrytion ... but ...
 use Exporter; @ISA = qw(Exporter);
@@ -587,22 +587,22 @@ Tea.pm - The Tiny Encryption Algorithm in Perl and JavaScript
 
 Usage:
 
-	use Crypt::Tea;
-	$key = 'PUFgob$*LKDF D)(F IDD&P?/';
-	$ascii_cyphertext = &encrypt ($plaintext, $key);
-	...
-	$plaintext_again = &decrypt ($ascii_cyphertext, $key);
-	...
-	$signature = &asciidigest ($text);
+ use Crypt::Tea;
+ $key = 'PUFgob$*LKDF D)(F IDD&P?/';
+ $ascii_cyphertext = &encrypt ($plaintext, $key);
+ ...
+ $plaintext_again = &decrypt ($ascii_cyphertext, $key);
+ ...
+ $signature = &asciidigest ($text);
 
 In CGI scripts:
 
-	use Crypt::Tea;
-	print &tea_in_javascript;
-   # now the browser can encrypt and decrypt ! In JS:
-   var ascii_ciphertext = encrypt (plaintext, key);
-   var plaintext_again  = decrypt (ascii_ciphertext, key);
-   var signature = asciidigest (text);
+ use Crypt::Tea;
+ print &tea_in_javascript;
+ # now the browser can encrypt and decrypt ! In JS:
+ var ascii_ciphertext = encrypt (plaintext, key);
+ var plaintext_again  = decrypt (ascii_ciphertext, key);
+ var signature = asciidigest (text);
 
 =head1 DESCRIPTION
 
@@ -612,7 +612,7 @@ and some Modes of Use, in Perl and JavaScript.
 The $key is a sufficiently longish string; at least 17 random 8-bit
 bytes for single encryption.
 
-Version 2.05,
+Version 2.06,
 #COMMENT#
 
 (c) Peter J Billam 1998
@@ -676,7 +676,7 @@ On the server, typically you will retrieve the Key from a
 database of some sort, for example:
 
  $plaintext = "<P>Hello World !</P>\n";
- dbmopen %keys, '/home/wherever/passwords';
+ dbmopen %keys, "/home/wherever/passwords";
  $key = $keys{$username};
  dbmclose %keys;
  $cyphertext = &encrypt ($plaintext, $key);
@@ -693,14 +693,14 @@ they view an encrypted page, or submit a form.
  </SCRIPT>
  EOT
 
-To submit a FORM with encrypted cyphertext, the neatest way is to
-contruct two FORMs; one overt one which the user fills in but which never
-actually gets submitted, and one covert one which will hold the cyphertext.
+To submit an encrypted FORM, the neatest way is to contruct two FORMs;
+one overt one which the user fills in but which never actually gets
+submitted, and one covert one which will hold the cyphertext.
 
  print <<'EOT';
  <SCRIPT LANGUAGE="JavaScript"> <!--
  function submitter (form) { // NB: a javascript: url passes the frame
-   var plaintext = '';
+   var plaintext = "";
    for (var i=0; i<form.length; i++) { // construct ff-separated list
      var e = form.elements[i];
      plaintext += (e.name+"\f"+ e.value+"\f"); 
@@ -733,7 +733,7 @@ See the cgi script examples/tea_demo.cgi in the distribution directory.
 
 If you want the browser to remember its Key from page to page,
 to form a session, then things get harder.
-If you store the Key in a Cookie, then it is vulnerable to
+If you store the Key in a Cookie, it is vulnerable to
 any imposter server who imitates your IP address,
 and also to anyone who sits down at the user's computer.
 However, this remains the most practical option.
@@ -756,7 +756,7 @@ However, the digest (signature) functions of 1.xx and 2.xx differ
 in their use of '+' and '-' characters respectively.
 Version 1.45 will remain the final version in the 1.xx branch; the
 '+' character it used in the ascii-encoding is a reserved character
-in the query part of URLs; therefore versions 2.xx use '-' instead.
+in the query part of URLs.
 
 Crypt::Tea can conflict with a similarly-named Crypt::TEA by Abhijit
 Menon-Sen.  The functionality of Crypt::Tea is different from Abhijit's
@@ -765,12 +765,15 @@ ascii-encoded, and notably there is a subroutine to return JavaScript
 code which implements compatible functions. Unfortunately, Microsoft
 operating systems confuse the two names and are unable to install both.
 Therefore, after version 2.xx, further development in Crypt::Tea
-will take place under the name Crypt::Tea_PPJS.
+will take place probably under the name Crypt::Tea_PPJS.
+
+Currently this is vapourware, but candidate additions after the move to
+Crypt::Tea_PPJS could include Diffie-Hellman negotiation, triple-encryption,
+the use of the newer Tea algorithm
+(which would sacrifice backward-compatibility),
+and some use of C for extra speed
+(which would not fit the PP bit of the new name).
 
-Currently this is vapourware, but candidate additions after the
-move to Crypt::Tea_PPJS could include Diffie-Hellman negotiation,
-triple-encryption, the use of the newer Tea algorithm, and some use
-of C for extra speed.
 
 =head1 AUTHOR
 
